Flux-Sensitivity
================
|BlackStyle|

You have an instrument that is looking for the photons coming from point like sources?
Your instrument can estimate the energy of the photons?
Your instrument suffers from a background which it falsely classifies as photons?

This tool estimates how much flux photons must be present at your instrument in order to claim a detection of the photons source.

.. |BlackStyle| image:: https://img.shields.io/badge/code%20style-black-000000.svg
    :target: https://github.com/psf/black
